0.1.2 (31-07-2014)
------------------

- Documentation fixes and cleanup
- Removed RDFlib artefacts from output.

0.1.1 (20-05-2014)
------------------

- Bugfixing
- encoding/decoding problems
- casting rdf subjects and objects to rdflib URI's
- Added tests

0.1.0
-----

- Initial version
